# What's Changed

1. 新增：WebUI 支持暗夜模式。
2. 修复：修复 WebUI Chat 接口的未授权访问安全漏洞、插件 README 可能存在的 XSS 注入漏洞。
3. 优化：优化 Vec DB 在 indexing 过程时的数据库事务处理。
4. 修复：WebUI 下，插件市场的推荐卡片无法点击帮助文档的问题。
5. 新增：知识库。
6. 新增：WebUI 提供商测试功能，一键检测可用性。
7. 新增：WebUI 提供商分类功能，按能力分类提供商。
